@@ -96,6 +96,11 @@ class {package_name}Conan(Sense2File):
         package_name = self.name
         deb_file = package_name + ".deb"
         self.copy(deb_file, dst=".", keep_path=False)
+
+        if os.path.exists(package_name):
+            self.run("rm -rf " + package_name)
+        
+        self.run("rm -rf *.deb")
         pass
         
     def install_deb(self):
