@@ -122,10 +122,9 @@ class CmdUploadDeb(CmdUpload):
 
         pkg_layout = self._cache.package_layout(pref.ref)
         conanfile_path = pkg_layout.conanfile()
+        package_fold = pkg_layout.package(pref)
+        conanfile = self._graph_manager.load_consumer_conanfile(conanfile_path, package_fold)
         
-        install_fold = pkg_layout.build(pref)
-        conanfile = self._graph_manager.load_consumer_conanfile(conanfile_path, install_fold,
-                                                                   deps_info_required=True)
         deb_folder = pkg_layout.deb(pref)
         deb_file = os.path.join(deb_folder, conanfile.name + ".deb")
         
